==> advert-gp-3.2.4-sources.jar: com/yodo1/advert/utils/AppsflyerUtils.java <==
package com.yodo1.advert.utils;

import android.content.Context;

import com.yodo1.plugin.dmp.yodo1.constants.AnalyticsConst;
import com.yodo1.sdk.kit.YLog;

import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;

/**
 * Created by zhuxiaochen on 2018/4/3.
 */

public class AppsflyerUtils {
    private static final String TAG = "[AppsflyerUtils] ";

    public static final String AF_VIDEO_EVENT_NAME = "APPSFLYER_VIDEO"; //视频广告播放完
    public static final String AF_INTERSTITIAL_EVENT_NAME = "APPSFLYER_INTERSTITIAL"; //插屏广告关闭

    public static final String AF_AD_MONETIZED_EVENT_NAME = "Ad_Monetized";

    public static final String AD_TYPE = "Type";

    public static final String AD_TYPE_INTERSTITIAL = "interstitial";
    public static final String AD_TYPE_VIDEO = "video";


    /**
     * appsflyer广告统计
     */
    public static void AF_Event(Context context, String eventId, String advertCode, String showResult, String type) {

        HashMap<String, Object> map = new HashMap<String, Object>();
        map.put(AnalyticsConst.AdvertCode, advertCode);
        map.put(AnalyticsConst.Result, showResult);
        map.put(AD_TYPE, type);

        try {
            Class clz = Class.forName("com.yodo1.analytics.helper.Yodo1AnalyticsHelper");
            Method m = clz.getMethod("onEventAppsflyer", String.class, Map.class);
            m.invoke(clz.newInstance(), eventId, map);
            return;
        } catch (Exception e) {
            YLog.d(TAG + "com.yodo1.analytics.helper.Yodo1AnalyticsHelper was not found");
        }

        YLog.d(TAG + "will find com.yodo1.android.sdk.helper.Yodo1AnalyticsHelper...");

        try {
            Class clz = Class.forName("com.yodo1.android.sdk.helper.Yodo1AnalyticsHelper");
            Method m = clz.getMethod("eventAppsflyer", String.class, Map.class);
            m.invoke(clz.newInstance(), eventId, map);
        } catch (Exception e) {
            YLog.d(TAG + "com.yodo1.android.sdk.helper.Yodo1AnalyticsHelper was not found");
        }
    }

}

==> advert-gp-3.7.0-sources.jar: com/yodo1/advert/utils/AppsflyerUtils.java <==
package com.yodo1.advert.utils;

import android.content.Context;

import com.yodo1.plugin.dmp.yodo1.constants.AnalyticsConst;
import com.yodo1.sdk.kit.YLog;

import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;

/**
 * @author zhuxiaochen
 */
public class AppsflyerUtils {
    private static final String TAG = "[AppsflyerUtils] ";

//    public static final String AF_VIDEO_EVENT_NAME = "APPSFLYER_VIDEO"; //视频广告播放完
//    public static final String AF_INTERSTITIAL_EVENT_NAME = "APPSFLYER_INTERSTITIAL"; //插屏广告关闭

    public static final String AF_AD_MONETIZED_EVENT_NAME = "Ad_Monetized";

    public static final String AD_TYPE_INTERSTITIAL = "interstitial";
    public static final String AD_TYPE_VIDEO = "video";

    private static final String AD_TYPE = "Type";

    /**
     * appsflyer广告统计
     */
    public static void AF_Event(Context context, String eventId, String advertCode, String showResult, String type) {

        HashMap<String, Object> map = new HashMap<String, Object>();
        map.put(AnalyticsConst.AdvertCode, advertCode);
        map.put(AnalyticsConst.Result, showResult);
        map.put(AD_TYPE, type);

        try {
            Class clz = Class.forName("com.yodo1.analytics.helper.Yodo1AnalyticsHelper");
            Method m = clz.getMethod("onEventAppsflyer", String.class, Map.class);
            m.invoke(clz.newInstance(), eventId, map);
            return;
        } catch (Exception e) {
            YLog.d(TAG + "com.yodo1.analytics.helper.Yodo1AnalyticsHelper was not found");
        }

        YLog.d(TAG + "will find com.yodo1.android.sdk.helper.Yodo1AnalyticsHelper...");

        try {
            Class clz = Class.forName("com.yodo1.android.sdk.helper.Yodo1AnalyticsHelper");
            Method m = clz.getMethod("eventAppsflyer", String.class, Map.class);
            m.invoke(clz.newInstance(), eventId, map);
        } catch (Exception e) {
            YLog.d(TAG + "com.yodo1.android.sdk.helper.Yodo1AnalyticsHelper was not found");
        }
    }

}
